@@ -1,5 +1,5 @@
 ;; jde-run.el --- runs the Java app in the current buffer.
-;; $Revision: 1.18 $ $Date: 1998/07/02 05:36:00 $
+;; $Revision: 1.20 $ $Date: 1998/09/11 23:53:32 $
 
 ;; Author: Paul Kinnucan <paulk@mathworks.com>
 ;; Maintainer: Paul Kinnucan
@@ -50,6 +50,13 @@ method."
   :group 'jde-project
   :type 'string)
 
+(defcustom jde-run-working-directory ""
+  "*Path of the working directory for this application.
+If you specify a path, the JDE launches the application from the
+directory specified by the path."
+  :group 'jde-project
+  :type 'string)
+
 
 (defcustom jde-run-java-vm "java"
   "*Specify Java interpreter for non-Windows platforms."
@@ -500,16 +507,19 @@ input from the buffer to the program."
     (jde-run-internal app-class)))
 
 (defmacro save-w32-show-window (&rest body)
-"Saves the value of the w32-start-process-show-window variable
+  "Saves the value of the w32-start-process-show-window variable
 before evaluating body and restores the value afterwards."
-  `(if (and 
-	(eq system-type 'windows-nt)
-	(boundp 'win32-start-process-show-window))
-       (let ((save win32-start-process-show-window))
-	 (setq win32-start-process-show-window t)
-	 ,@body
-	 (setq win32-start-process-show-window save))
-    ,@body))
+  `(if (eq system-type 'windows-nt)
+       (if (boundp 'win32-start-process-show-window)
+	   (let ((save win32-start-process-show-window))
+	     (setq win32-start-process-show-window t)
+	     ,@body
+	     (setq win32-start-process-show-window save))
+	 (let ((save w32-start-process-show-window))
+	   (setq w32-start-process-show-window t)
+	   ,@body
+	   (setq w32-start-process-show-window save)))	 
+     ,@body))
 
 (defun jde-run-unquote (string)
   (if (eq (aref string 0) ?\")
@@ -517,7 +527,11 @@ before evaluating body and restores the value afterwards."
     string))
 
 (defun jde-run-internal(app-class)
-  (let ((run-buf-name (concat "*" app-class "*")))
+  (let ((run-buf-name (concat "*" app-class "*"))
+	(source-directory default-directory)
+	(working-directory (if (string= jde-run-working-directory "")
+			       default-directory
+			     jde-run-working-directory)))
     (if (not (comint-check-proc run-buf-name))
 	(let* ((run-buffer (get-buffer-create run-buf-name))
 	       (win32-p (eq system-type 'windows-nt))
@@ -552,12 +566,14 @@ before evaluating body and restores the value afterwards."
 	  (save-excursion
 	    (set-buffer run-buffer)
 	    (erase-buffer)
-	    (insert (concat "cd " default-directory "\n"))
+	    (cd working-directory)
+	    (insert (concat "cd " working-directory "\n"))
 	    (insert command-string)
 	    (jde-run-mode))
 	  (save-w32-show-window
 	   (comint-exec run-buffer app-class prog nil prog-args))
-	  (pop-to-buffer run-buffer))
+	  (pop-to-buffer run-buffer)
+	  (cd source-directory))
       (message "An instance of %s is running." app-class)
       (pop-to-buffer run-buf-name))))
 
@@ -663,6 +679,17 @@ and the applet document specified by jde-run-applet-doc."
 
 ;; Change History
 ;; $Log: jde-run.el $
+;; Revision 1.20  1998/09/11 23:53:32  paulk
+;; Added a jde-run-working-directory customization variable. If set to a valid
+;; path, the JDE starts the application from the directory specified by the
+;; path. If the value of this variable is the empty string (the default),
+;; the JDE starts the application from the default directory of the current
+;; source buffer. The default directory is usually the directory containing
+;; the source file.
+;;
+;; Revision 1.19  1998/08/28 12:49:23  paulk
+;; Updated to support NT/Emacs 20.3
+;;
 ;; Revision 1.18  1998/07/02 05:36:00  paulk
 ;; Added $ to the set of characters recognized by the JDE as valid
 ;; in vm and Java app command-line arguments.
