@@ -1,5 +1,5 @@
 ;;; jde.el -- Integrated Development Environment for Java.
-;; $Revision: 1.67 $ $Date: 1998/07/28 03:15:33 $ 
+;; $Revision: 1.73 $ $Date: 1998/09/13 02:01:53 $ 
 
 ;; Author: Paul Kinnucan <paulk@mathworks.com>
 ;; Maintainer: Paul Kinnucan
@@ -23,7 +23,7 @@
 ;; Boston, MA 02111-1307, USA.
 
 ;;;###autoload
-(defconst jde-version "2.0.9"
+(defconst jde-version "2.1.1"
   "JDE version number.")
 
 ;;; Commentary:
@@ -113,6 +113,34 @@
   :group 'jde
   :prefix "jde-")
 
+(defcustom jde-key-bindings
+  (list (cons "\C-c\C-v\C-c" 'jde-compile)
+	(cons "\C-c\C-v\C-r" 'jde-run)
+	(cons "\C-c\C-v\C-d" 'jde-db)
+	(cons "\C-c\C-v\C-b" 'jde-build)
+	(cons "\C-c\C-v\C-a" 'jde-run-menu-run-applet)
+	(cons "\C-c\C-v\C-n" 'jde-browse-jdk-doc)
+	(cons "\C-c\C-v\C-p" 'jde-save-project)
+	(cons "\C-c\C-v\C-l" 'jde-gen-println))
+  "*Specifies key bindings for the JDE.
+The value of this variable is an association list. The car of
+each element specifies a key sequence. The cdr specifies 
+an interactive command that the key sequence executes. To enter
+a key with a modifier, type C-q followed by the desired modified
+keystroke. For example, to enter C-s (Control s) as the key to be
+bound, type C-q C-s in the key field in the customization buffer."
+  :group 'jde-project
+  :type '(repeat
+	  (cons :tag "Key binding"
+	   (string :tag "Key")
+	   (function :tag "Command")))
+  :set '(lambda (sym val)
+	  (if (boundp 'jde-mode-map)
+	      (mapc (lambda (binding)
+		      (define-key jde-mode-map (car binding) (cdr binding)))
+		    val))
+	  (set-default sym val)))
+
 (defcustom jde-jdk-doc-url "http://www.javasoft.com/products/jdk/1.1/docs/index.html"
   "*URL of JDK documentation. 
 This can point to a remote or local copy of the documentation. By
@@ -791,6 +819,7 @@ to run the application's main class."
         ["-"                 ignore nil]
 	(list "Generate"
 	      ["Get/Set Pair..."  jde-gen-get-set t]
+	      ["Println..."       jde-gen-println t]
 	      (list "Listener"
 		    ["Action"          jde-gen-action-listener t]
 		    ["Window"          jde-gen-window-listener t]
@@ -865,19 +894,6 @@ to run the application's main class."
   (unless (featurep 'infodock)
     (add-submenu '("File") jde-new-buffer-menu "Insert File...")))
 
-
-
-;; Define jde-mode accelerator keys
-(define-key jde-mode-map "\C-c\C-v\C-c" 'jde-compile)
-(define-key jde-mode-map "\C-c\C-v\C-r" 'jde-run)
-(define-key jde-mode-map "\C-c\C-v\C-d" 'jde-db)
-(define-key jde-mode-map "\C-c\C-v\C-b" 'jde-build)
-(define-key jde-mode-map "\C-c\C-v\C-s" 'speedbar-frame-mode)
-(define-key jde-mode-map "\C-c\C-v\C-a" 'jde-run-menu-run-applet)
-(define-key jde-mode-map "\C-c\C-v\C-n" 'jde-browse-jdk-doc)
-(define-key jde-mode-map "\C-c\C-v\C-u" 'jde-update-buffer)
-(define-key jde-mode-map "\C-c\C-v\C-p" 'jde-save-project)
-
 ;; Project File Functions
 
 (defun jde-root-dir-p (dir)
@@ -1450,6 +1466,28 @@ pattern.
 ;; Change History
 ;;
 ;; $Log: jde.el $
+;; Revision 1.73  1998/09/13 02:01:53  paulk
+;; Fixed a small bug in key binding code.
+;;
+;; Revision 1.72  1998/09/13 01:49:35  paulk
+;; Added support for customization of JDE key bindings via the
+;; variable jde-key-bindings.
+;;
+;; Revision 1.71  1998/09/13 00:32:48  paulk
+;; Added System.out.println template to the Generate menu.
+;;
+;; Revision 1.70  1998/09/07 02:50:31  paulk
+;; This version includes the latest version of jde-gen.el, which was inadvertently
+;; replaced by an older version in the last release. This version also includes
+;; a newer version of speedbar.el that seems to work better with NT/Emacs 20.3.1
+;; than the one that comes with the 20.3.1 distribution.
+;;
+;; Revision 1.69  1998/08/28 12:56:06  paulk
+;; *** empty log message ***
+;;
+;; Revision 1.68  1998/08/28 12:52:52  paulk
+;; Updated version number.
+;;
 ;; Revision 1.67  1998/07/28 03:15:33  paulk
 ;; Removed a diagnostic message.
 ;;
